Command Line Interface
======================
oncvpsp_tools automatically installs the command :code:`oncvpsp-tools`. See
:code:`oncvpsp-tools --help` for usage details.

.. click:: oncvpsp_tools.cli:main
   :prog: oncvpsp-tools
   :show-nested:
